// Copyright (C) 2013 - Michael Baudin

//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_evinv (p, mu, sigma, lowertail)
    // Extreme value (Gumbel) Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_evinv ( p , mu , sigma )
    //   x = distfun_evinv ( p , mu , sigma , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   mu : a matrix of doubles, the location.
    //   sigma : a matrix of doubles, the scale. sigma>0.
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome
    //
    // Description
    //   Computes the inverse cumulated probability distribution function of the Extreme value (Gumbel) function.
    //   This is the minimum Gumbel distribution.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // Examples
    // x = distfun_evinv([0.5 0.9 0.7],0,1)
    // expected = [-0.3665129 0.8340324 0.1856268]
    //
    // x=1;
    // mu=0.5;
    // sigma=2.;
    // lowertail=%t;
    // p=distfun_evcdf(x,mu,sigma,lowertail);
    // x1=distfun_evinv(p,mu,sigma,lowertail)
    // //
    // lowertail=%f;
    // p=distfun_evcdf(x,mu,sigma,lowertail);
    // x1=distfun_evinv(p,mu,sigma,lowertail)
    //
    // Authors
    //   Copyright (C) 2013 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        mu {mustBeA(mu, "double")}
        sigma {mustBeA(sigma, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny")
    if sigma < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_evinv", 3, tiny));
    end

    [p, mu, sigma] = distfun_expandvar("distfun_evinv", p, mu, sigma)

    x=distfun_invev(p,mu,sigma,lowertail)
endfunction

