// Copyright (C) 2012 - Prateek Papriwal
// Copyright (C) 2012 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
//

function x = distfun_finv(p, v1, v2, lowertail)
    // F-distribution Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_finv(p,v1,v2)
    //   x = distfun_finv(p,v1,v2,lowertail)
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   v1 : a matrix of doubles, numerator degrees of freedom, v1>0 (can be non integer). 
    //   v2 : a matrix of doubles, denominator degrees of freedom, v2>0 (can be non integer). 
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=p) otherwise P(X>p).
    //   x : a matrix of doubles. x is real and p>=0.
    //
    // Description
    //   Computes the Inverse cumulative distribution function of 
    //   the f distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles 
    //   of the same size as the other input arguments.
    //
    // Examples
    //
    // // Test with p,v1,v2 scalar
    // computed = distfun_finv(0.95,5,10)
    // expected = 3.325834530413011247D+00
    //
    // // Test with p expanded, v1 and v2 scalar
    // computed = distfun_finv([0.5 0.95],5,10)
    // expected = [
	// 9.319331608510478260D-01 
	// 3.325834530413011247D+00
	// ]'
    //
    // // Test with p scalar, v1 and v2 expanded
    // computed = distfun_finv(0.95,[5 10],[10 5])
    // expected = [
	// 3.325834530413011247D+00 
	// 4.735063069693421944D+00
	// ]
    //
    // // Test with p,v1,v2 expanded
    // computed = distfun_finv([0.5 0.95],[5 10],[10 5])
    // expected = [
	// 9.319331608510478260D-01 
	// 4.735063069693421944D+00
	// ]
    //
    // // Test with small value of p
    // computed = distfun_finv(1.e-15,5,10)
    // expected = 5.660986432909706613D-07
    //
    // Bibliography
    // http://en.wikipedia.org/wiki/F-distribution
    //
    // Authors
    // Copyright (C) 2012 - Prateek Papriwal
    // Copyright (C) 2012 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        v1 {mustBeA(v1, "double")}
        v2 {mustBeA(v2, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiniest=number_properties("tiniest")
    if v1 < tiniest then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_finv", 2, tiniest));
    end

    if v2 < tiniest then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_finv", 3, tiniest));
    end

    [p, v1, v2] = distfun_expandvar("distfun_finv", p, v1, v2);
    
    x = distfun_invf(p,v1,v2,lowertail)
endfunction
