// Copyright (C) 2012 - 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function y = distfun_genericpdf(x,__cdffun__,iscontinuous)
    // Compute the PDF from the CDF.
    //
    // Calling Sequence
    //    distfun_genericpdf(x,cdffun)
    //    distfun_genericpdf(x,cdffun,iscontinuous)
    //
    // Parameters
    // x : a matrix of doubles, the points where to evaluate the PDF.
    // cdffun : a list, the CDF function and its arguments
    // iscontinuous : a 1-by-1 matrix of booleans, %t for continuous variables, %f for integer variables (default iscontinuous=%t)
    // y : a matrix of doubles, the density
    //
    // Description
    // The distfun_genericpdf function computes the PDF 
    // from a given CDF, by derivation. 
    //
    // The CDF function should have header :
    //
	// <programlisting>
    // p=cdffun(x,a)
    // p=cdffun(x,a,b)
    // p=cdffun(x,a,b,c)
	// </programlisting>
    //
    // The cdffun function must be a list(f,a) or 
    // (f,a,b) or (f,a,b,c) where 
    // f is the PDF function and a, b, or c scalars which are automatically 
    // added at the end of the calling sequence.
    //
    // The performance of this function may be poor.
    //
    // Examples
    // x=3;
    // v1=5;
    // v2=6;
    // distfun_genericpdf(x,list(distfun_fcdf,v1,v2))
    // // Check with the exact PDF
    // distfun_fpdf(x,v1,v2)
    //
    // // Integer distribution
    // x=3;
    // pr = 0.3;
    // computed = distfun_genericpdf(x,list(distfun_geocdf,pr),%f)
    // expected = distfun_geopdf(x,pr)
    //
    // Authors
    //   Copyright (C) 2012 - 2014 - Michael Baudin

    arguments
        x {mustBeA(x, "double")}
        __cdffun__ {mustBeA(__cdffun__, "list")}
        iscontinuous {mustBeA(iscontinuous, "boolean"), mustBeScalar} = %t
    end
    //
    // Analyse the list
    __cdffun__f = __cdffun__(1)
    if and(type(__cdffun__f) <> [13 130]) then
        error(msprintf(_("%s: Wrong type for input argument #%d of list: A function expected.\n"), "distfun_genericpdf", 1));
    end
    for i=2:length(__cdffun__)
        if type( __cdffun__(i)) <> 1 then
            error(msprintf(_("%s: Wrong type for input argument #%d of list: A double expected.\n"), "distfun_genericpdf", i));
        end
        if size( __cdffun__(i), "*") <> 1 then
            error(msprintf(_("%s: Wrong type for input argument #%d of list: A scalar expected.\n"), "distfun_genericpdf", i));
        end
    end
    //
    nrows = size(x,"r")
    ncols = size(x,"c")
    //
    for i=1:nrows*ncols
        if (iscontinuous) then
            y(i) = numderivative(list(__cdffun__f,__cdffun__(2:$)),x(i))
        else
            y1=__cdffun__f(x(i),__cdffun__(2:$))
            y2=__cdffun__f(x(i)-1,__cdffun__(2:$))
            y(i)=y1-y2
        end
    end
    y=matrix(y,nrows,ncols)
endfunction
