// Copyright (C) 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


function x=distfun_histoinv(p, h, lowertail)
    // Histogram inverse CDF
    //  
    // Calling Sequence
    //   x=distfun_histoinv(p,h)
    //   x=distfun_histoinv(p,h,lowertail)
    //
    // Parameters
    // p : a matrix of doubles, the probability
    // h : an histogram object
    // lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    // x : a matrix of doubles, the outcome
    //
    // Description
    // Computes the inverse cumulated probability distribution function of the 
    // Histogram.
    //
    // The h object must be created with distfun_histocreate.
    //
    // Examples
    // m=1000;
    // data=distfun_normrnd(0,1,m,1);
    // h=distfun_histocreate("data",data);
    // p=linspace(0.001,0.999);
    // x=distfun_histoinv(p,h);
    // scf();
    // plot(p,x,"r-")
    // xnorm=distfun_norminv(p,0,1);
    // plot(p,xnorm,"b-")
    // legend(["Histogram","Exact"],"in_upper_left");
    // xtitle("Histogram")
    // xlabel("p")
    // ylabel("x|P(X<x)=p")
    //
    // Authors
    // Copyright (C) 2014 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        h {mustBeA(h, "struct")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    // Proceed...
    if (~lowertail) then
        p=1-p
    end
    x=zeros(p)
    ibins=dsearch(p,h.cdf)
    //
    jindices=find(ibins==0)
    x(jindices)=h.edges(1)
    //
    jindices=find(ibins>0)
    q=h.edges(ibins(jindices)+1)
    // Reformat the matrix shape
    x(jindices)=matrix(q,size(p(jindices)))
endfunction
