// Copyright (C) 2013 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt



function x = distfun_loguinv (p, a, b, lowertail)
    // LogUniform Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_loguinv ( p , a , b )
    //   x = distfun_loguinv ( p , a , b , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   a: a matrix of doubles, the minimum of the underlying uniform variable. 
    //   b: a matrix of doubles, the maximum of the underlying uniform variable. b>a.
    // lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    // x: a matrix of doubles
    //
    // Description
    //   This function computes the LogUniform quantile.
    //
    //   Any scalar input argument is expanded to a matrix of doubles of the same size 
    //   as the other input arguments.
    //
    // Any optional input argument equal to the empty matrix will be set to its
    // default value.
    //
    // Examples
    // x=distfun_loguinv(0.6,1,2)
    // xexpected = 4.9530324
    //
    // // Check the inverse LogUniforme
    // a=1;
    // b=10;
    // x=exp(2)
    // p=distfun_logucdf(x,a,b)
    // x=distfun_loguinv(p,a,b) // Must be exp(2)
    //
    // // Test upper tail
    // x=distfun_loguinv(0.1,1,2,%f) // 6.6858944
    //
    // Authors
    // Copyright (C) 2013 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        a {mustBeA(a, "double")}
        b {mustBeA(b, "double"), mustBeGreaterThanOrEqual(b, a)}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    if (a==[]) then
        x=[]
        return
    end

    [p, a, b] = distfun_expandvar ("distfun_loguinv", p, a, b)
    
    if (lowertail) then
        x=exp(a+p.*(b-a))
    else
        x=exp(b+p.*(a-b))
    end
endfunction

