// Copyright (C) 2013 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_logurnd ( varargin )
    // LogUniform random numbers
    //
    // Calling Sequence
    //   x = distfun_logurnd ( a , b )
    //   x = distfun_logurnd ( a , b , [m,n] )
    //   x = distfun_logurnd ( a , b , m , n )
    //
    // Parameters
    //   a: a matrix of doubles, the minimum of the underlying uniform variable. 
    //   b: a matrix of doubles, the maximum of the underlying uniform variable. b>a.
    //   m : a 1-by-1 matrix of floating point integers, the number of rows of x
    //   n : a 1-by-1 matrix of floating point integers, the number of columns of x
    //   x: a matrix of doubles, the positive random numbers.
    //
    // Description
    //   Generates random variables from the LogUniform distribution function.
    //
    //   Any scalar input argument is expanded to a matrix of doubles of 
	//   the same size as the other input arguments.
    // 
    // Examples
    // // Test both a and b expanded
    // computed = distfun_logurnd(1:6,2:7)
    //
    // // Test a expansion
    // computed = distfun_logurnd(1:6,7)
    //
    // // Test b expansion
    // computed = distfun_logurnd(0,1:6)
    //
    // // Test with v
    // computed = distfun_logurnd(0,1,[3 2])
    //
    // // Test with m, n
    // computed = distfun_logurnd(0,1,3,2)
    //
    // // Make a plot of the actual distribution of the numbers
	// // Compare random numbers with PDF
    // a=2;
    // b=3.5;
    // N=10000;
    // x=linspace(exp(a),exp(b),1000);
    // y=distfun_logupdf(x,a,b);
    // r=distfun_logurnd(a,b,N,1);
    // scf();
    // histplot(20,r)
    // plot(x,y)
    // xtitle("Log-Uniform","X","");
    // legend(["Data","PDF"]);
    //
    // Authors
    //   Copyright (C) 2013 - Michael Baudin

    select nargin
    case 2
        a = varargin(1)
        b = varargin(2)
        x = %distfun_logurnd(a, b);
    case 3
        a = varargin(1)
        b = varargin(2)
        v = varargin(3)
        x = %distfun_logurnd(a, b, v);
    case 4
        x = %distfun_logurnd(varargin(:));
    else
        error(msprintf(gettext("%s: Wrong number of input argument.\n"),"distfun_logurnd"));
    end
endfunction

function x = %distfun_logurnd(a, b, m, n)
    arguments
        a {mustBeA(a, "double")}
        b {mustBeA(b, "double"), mustBeGreaterThanOrEqual(b, a)}
        m {mustBeA(m, "double"), mustBeInteger, mustBeGreaterThanOrEqual(m, 0)} = []
        n {mustBeA(n, "double"), mustBeScalarOrEmpty, mustBeInteger, mustBeGreaterThanOrEqual(n, 0)} = []
    end

    if (a==[]) then
        x=[]
        return
    end

    select nargin 
    case 2
        [a,b]=distfun_expandvar("distfun_logurnd", a, b)
        m = size(a, "r");
        n = size(a, "c");
    case 3
        if size(m, "*") <> 2 then
            error(msprintf(_("%s: Wrong size for input argument #%d: A vector of length %d expected.\n"), "distfun_logurnd", 3, 2));
        end
        n = m(2);
        m = m(1);
    end

    if nargin > 2 then

        if(( size(a,"*") == 1)) then
            a = a * ones(m, n);
        else 
            if or(size(a) <> [m,n]) then
                error(msprintf(_("%s: Wrong size for input argument #%d: Must be of size %d x %d.\n"), "distfun_logurnd", 1, m, n));
            end
        end
        if(( size(b,"*") == 1)) then
            b = b * ones(m, n);
        else 
            if or(size(b) <> [m,n]) then
                error(msprintf(_("%s: Wrong size for input argument #%d: Must be of size %d x %d.\n"), "distfun_logurnd", 2, m, n));
            end
        end
    end

    u=distfun_unifrnd(a,b,m,n)
    x=exp(u)
endfunction

