// Copyright (C) 2013 - 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function [M,V] = distfun_logustat ( a, b )
    // LogUniform mean and variance
    //
    // Calling Sequence
    //   M = distfun_logustat ( a , b )
    //   [M,V] = distfun_logustat ( a , b )
    //
    // Parameters
    // a: a matrix of doubles, the minimum of the underlying uniform variable. 
    // b: a matrix of doubles, the maximum of the underlying uniform variable. b>a.
    //   M : a matrix of doubles, the mean
    //   V : a matrix of doubles, the variance
    //
    // Description
    //   Computes statistics from the LogUniform distribution.
    //
    // The mean and variance of the LogUniform distribution are
    //
    //<latex>
    //\begin{eqnarray}
    // M&=&\frac{\exp(b)-\exp(a)}{b-a} \\
    // V&=&\frac{1}{2} \frac{\exp(b)^2-\exp(a)^2}{b-a}-M^2
    //\end{eqnarray}
    //</latex>
    //
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // Examples
    // a = 1:6;
    // b = 2:7;
    // [M,V]=distfun_logustat(a,b)
    //
    // Authors
    //   Copyright (C) 2013 - 2014 - Michael Baudin

    arguments
        a {mustBeA(a, "double")}
        b {mustBeA(b, "double"), mustBeGreaterThanOrEqual(b, a)}
    end

    if (a==[]) then
        M=[]
        V=[]
        return
    end

    [a, b] = distfun_expandvar ("distfun_logustat", a, b)
    
    M=(exp(b)-exp(a))./(b-a)
    V=0.5*(exp(b).^2-exp(a).^2)./(b-a)-M.^2
endfunction

