// Copyright (C) 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
//

function x = distfun_ncfinv(p,v1,v2,delta,lowertail)
    // Noncentral F Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_ncfinv(p,v1,v2,delta)
    //   x = distfun_ncfinv(p,v1,v2,delta,lowertail)
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   v1 : a matrix of doubles, numerator degrees of freedom, v1>0 (can be non integer). 
    //   v2 : a matrix of doubles, denominator degrees of freedom, v2>0 (can be non integer). 
    //   delta : a matrix of doubles, the noncentrality parameter, delta>=0
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles. x is real and x>=0.
    //
    // Description
    //   Computes the Inverse cumulative distribution function of 
    //   the Noncentral F distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles 
    //   of the same size as the other input arguments.
    //
    // <emphasis>Caution</emphasis>
    // This distribution is known to have inferior accuracy in 
    // some cases.
    //
    // Examples
    // computed = distfun_ncfinv(0.7, 4, 12, 0.3)
    // expected = 1.4786561151681499
    //
    // // Test with small value of p
    // computed = distfun_ncfinv(1.e-15,4, 12, 0.3)
    // expected = 3.342537766492919456D-07
    //
    // Bibliography
    // http://en.wikipedia.org/wiki/Noncentral_F-distribution
    //
    // Authors
    // Copyright (C) 2014 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        v1 {mustBeA(v1, "double")}
        v2 {mustBeA(v2, "double")}
        delta {mustBeA(delta, "double"), mustBeNonnegative}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiniest=number_properties("tiniest")
    if v1 < tiniest then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_ncfinv", 2, tiniest));
    end

    if v2 < tiniest then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_ncfinv", 3, tiniest));
    end

    [p,v1,v2,delta] = distfun_expandvar("distfun_ncfinv",p,v1,v2,delta)

    x = distfun_invncf(p,v1,v2,delta,lowertail)
endfunction
