// Copyright (C) 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_nctinv(p, v, delta, lowertail)
    // Noncentral T Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_nctinv ( p , v , delta )
    //   x = distfun_nctinv ( p , v , delta , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   v : a matrix of doubles, the number of degrees of freedom, v>0. 
    //   delta : a matrix of doubles, the noncentrality parameter, delta is real
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome
    //
    // Description
    // Computes the Inverse Noncentral T cumulative probability distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // <emphasis>Caution</emphasis>
    // This distribution is known to have inferior accuracy in 
    // some cases.
    //
    // Examples
    // x = distfun_nctinv(0.7,5,10)
    // expected=8.9885923
    //
    // Authors
    // Copyright (C) 2014 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        v {mustBeA(v, "double")}
        delta {mustBeA(delta, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny") 
    if v < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_nctinv", 2, tiny));
    end

    [p,v,delta] = distfun_expandvar("distfun_nctinv",p,v,delta)

    x = distfun_invnct(p,v,delta,lowertail)
endfunction
