// Copyright (C) 2012 - Michael Baudin
// Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_norminv (p, mu, sigma, lowertail)
    // Normal Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_norminv ( p , mu , sigma )
    //   x = distfun_norminv ( p , mu , sigma , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   mu : a matrix of doubles, the mean.
    //   sigma : a matrix of doubles, the standard deviation. sigma>0.
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome
    //
    // Description
    //   Computes the inverse Normal cumulated probability distribution function of the Normal (Laplace-Gauss) function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // Examples
    // // Test with default mu, sigma
    // x = distfun_norminv ( [0.5 0.9 0.7] , 0 , 1 )
    // expected = [ ..
    // 0.000000000000000 , ..
    // 1.281551565544601 , ..
    // 0.524400512708041 ..
    // ]
    //
    // // Test argument expansion
    // x=distfun_norminv([0.5 0.9 0.7],1.0,2.0)
    // expected = [ ..
    //  1.00000000000000 , ..
    //  3.56310313108920 , ..
    //  2.04880102541608 ..
    // ]
    //
    // // Test with expanded arguments
    // x=distfun_norminv([0.5 0.9 0.7],[1 1 1],[2 2 2])
    // expected = [ ..
    // 1.00000000000000 , ..
    // 3.56310313108920 , ..
    // 2.04880102541608 ..
    // ]
    //
    // // See upper tail
    // x=distfun_norminv(0.0001,1.,2.,%f)
    // // See an extreme case
    // x=distfun_norminv(1.e-20,1.,2.,%f)
    //
    // Authors
    //   Copyright (C) 2009 - 2011 - DIGITEO - Michael Baudin
    //   Copyright (C) 2012 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        mu {mustBeA(mu, "double")}
        sigma {mustBeA(sigma, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny") 
    if sigma < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_norminv", 3, tiny));
    end

    [p, mu, sigma] = distfun_expandvar("distfun_norminv",p, mu, sigma)

    x = distfun_invnorm(p,mu,sigma,lowertail)
endfunction

