// Copyright (C) 2012 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function [M,V] = distfun_normstat ( mu, sigma )
  // Normal  mean and variance
  //
  // Calling Sequence
  //   M = distfun_normstat ( mu , sigma )
  //   [M,V] = distfun_normstat ( mu , sigma )
  //
  // Parameters
  //   mu : a matrix of doubles, the average
  //   sigma : a matrix of doubles, the standard deviation. sigma>0.
  //   M : a matrix of doubles, the mean
  //   V : a matrix of doubles, the variance
  //
  // Description
  //   Computes statistics from the Normal distribution.
  //
  // The mean and variance of the Normal distribution are
  //
  //<latex>
  //\begin{eqnarray}
  // M &=& \mu \\
  // V &=& \sigma^2
  //\end{eqnarray}
  //</latex>
  //
  //   Any scalar input argument is expanded to a matrix of 
  //   doubles of the same size as the other input arguments.
  //
  // Examples
  //
  // mu = 1:6;
  // sigma = 7:12;
  // [M,V] = distfun_normstat ( mu , sigma )
  // me = 1:6;
  // ve = [49. 64. 81. 100. 121. 144.];
  //
  // Authors
  //   Copyright (C) 2011 - DIGITEO - Michael Baudin

  arguments
    mu {mustBeA(mu, "double")}
    sigma {mustBeA(sigma, "double")}
  end

  tiny=number_properties("tiny") 
  if sigma < tiny then
      error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_normstat", 2, tiny));
  end

  [mu, sigma] = distfun_expandvar("distfun_normstat", mu, sigma)

  //
  M = mu
  V = sigma.^2
endfunction

