// Copyright (C) 2012 - Prateek Papriwal
// Copyright (C) 2012 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
//

function x = distfun_poissinv(p, lambda, lowertail)
    //  Poisson Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_poissinv(p,lambda)
    //   x = distfun_poissinv(p,lambda,lowertail)
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   lambda : a matrix of doubles, the average rate of occurrence. lambda>0.
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome. x belongs to the set {0,1,2,3,......}
    //
    // Description
    //   Computes the Inverse cumulative distribution function of 
    //   the Poisson distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles 
    //   of the same size as the other input arguments.
    //
    // Examples
    // // Test with p scalar, lambda scalar
    //x = distfun_poissinv(0.999,5)
    //expected = 13;
    //x = distfun_poissinv(1-0.999,5,%f)
    //expected = 13;
    //
    // // Test with expanded p , scalar lambda
    //x = distfun_poissinv([0.32 0.3],2)
    //expected = [1. 1.];
    //
    // // Test with scalar p, expanded lambda
    // x = distfun_poissinv(0.22,[3 2])
    // expected = [2. 1.];
    //
    //
    // // Test small values of p
    // x = distfun_poissinv(1.e-15,1)
    // expected = 0.;
    // x = distfun_poissinv(1.e-15,1,%f)
    // expected = 17.;
	//
    // Bibliography
    // http://en.wikipedia.org/wiki/Poisson_distribution
    //
    // Authors
    // Copyright (C) 2012 - Prateek Papriwal
    // Copyright (C) 2012 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        lambda {mustBeA(lambda, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny") 
    if lambda < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_poissinv", 2, tiny));
    end

    [p, lambda] = distfun_expandvar("distfun_poissinv", p, lambda)

    x = distfun_invpoiss(p,lambda,lowertail)
endfunction
