// Copyright (C) 2012 - Prateek Papriwal
// Copyright (C) 2012 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_tinv(p, v, lowertail)
    // T Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_tinv ( p , v )
    //   x = distfun_tinv ( p , v , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   v : a matrix of doubles, the number of degrees of freedom, v>0. 
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome
    //
    // Description
    // Computes the Inverse T cumulative probability distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // Examples
    // x = distfun_tinv(0.999,5) // 5.8934295
    //
    // // With extreme values of p
    // x = distfun_tinv(0,5) // x=-Inf
    // x = distfun_tinv(1,5) // x=+Inf
    //
    // // With lower tail
    // x = distfun_tinv(1.e-20,5,%f) // 15683.925
    //
    // Authors
    // Copyright (C) 2012 - Prateek Papriwal
    // Copyright (C) 2012 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        v {mustBeA(v, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny") 
    if v < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_tinv", 2, tiny));
    end

    [p, v] = distfun_expandvar("distfun_tinv", p, v)

    x = distfun_invt(p,v,lowertail)
endfunction
