// Copyright (C) 2014 - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

function x = distfun_wblinv (p , a , b , lowertail)
    // Weibull Inverse CDF
    //
    // Calling Sequence
    //   x = distfun_wblinv ( p , a , b )
    //   x = distfun_wblinv ( p , a , b , lowertail )
    //
    // Parameters
    //   p : a matrix of doubles, the probability. Must be in the range [0,1].
    //   a : a matrix of doubles, the scale parameter, a>0.
    //   b : a matrix of doubles, the shape parameter, b>0.
    //   lowertail : a 1-by-1 matrix of booleans, the tail (default lowertail=%t). If lowertail is true (the default), then considers P(X<=x) otherwise P(X>x).
    //   x : a matrix of doubles, the outcome
    //
    // Description
    // Computes the Inverse Weibull cumulative probability distribution function.
    //   
    //   Any scalar input argument is expanded to a matrix of doubles of the same size as the other input arguments.
    //
    // Examples
    // // Check expansion of a and b
    // p = [0.01 0.5 0.99];
    // x = distfun_wblinv(p,10,5)
    // expected = [3.9850715  9.2931959  13.572165]
    //
    // // See upper tail
    // p = [0.01 0.5 0.99];
    // x = distfun_wblinv(p,[8 9 10],[5 6 7])
    // x = distfun_wblinv(p,[8 9 10],[5 6 7],%f)
    //
    // Authors
    //  Copyright (C) 2014 - Michael Baudin

    arguments
        p {mustBeA(p, "double"), mustBeInRange(p, 0, 1)}
        a {mustBeA(a, "double")}
        b {mustBeA(b, "double")}
        lowertail {mustBeA(lowertail, "boolean"), mustBeScalar} = %t
    end

    tiny=number_properties("tiny") 
    if a < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_wblinv", 2, tiny));
    end
    if b < tiny then
        error(msprintf(_("%s: Wrong value for input argument #%d: Must be greater or equal to %d.\n"), "distfun_wblinv", 3, tiny));
    end
    //
    [ p , a , b ] = distfun_expandvar ("distfun_wblinv", p , a , b )
    x = distfun_invwbl(p,a,b,lowertail)
endfunction

